pub struct ExerciseOptionsMultiAccounts {Show 18 fields
pub payer: Pubkey,
pub tenant: Pubkey,
pub market_group: Pubkey,
pub market_meta: Pubkey,
pub market: Pubkey,
pub main_src: Pubkey,
pub options_src: Pubkey,
pub token_dst: Pubkey,
pub liq_vault_main: Pubkey,
pub mint_options: Pubkey,
pub mint_token: Pubkey,
pub mint_main: Pubkey,
pub rev_escrow_tenant: Pubkey,
pub rev_escrow_group: Pubkey,
pub token_program: Pubkey,
pub token_program_main: Pubkey,
pub log_account: Pubkey,
pub mayflower_program: Pubkey,
}Expand description
Generated client accounts for ExerciseOptionsMultiAccounts.
Fields
payer: Pubkeytenant: Pubkeymarket_group: Pubkeymarket_meta: Pubkeymarket: Pubkeymain_src: Pubkeyoptions_src: Pubkeytoken_dst: Pubkeyliq_vault_main: Pubkeymint_options: Pubkeymint_token: Pubkeymint_main: Pubkeyrev_escrow_tenant: Pubkeyrev_escrow_group: Pubkeytoken_program: Pubkeytoken_program_main: Pubkeylog_account: Pubkeymayflower_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ExerciseOptionsMultiAccountswhere
Pubkey: BorshSerialize,
impl BorshSerialize for ExerciseOptionsMultiAccountswhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for ExerciseOptionsMultiAccounts
impl ToAccountMetas for ExerciseOptionsMultiAccounts
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ExerciseOptionsMultiAccounts
impl RefUnwindSafe for ExerciseOptionsMultiAccounts
impl Send for ExerciseOptionsMultiAccounts
impl Sync for ExerciseOptionsMultiAccounts
impl Unpin for ExerciseOptionsMultiAccounts
impl UnwindSafe for ExerciseOptionsMultiAccounts