pub struct MarketGroupInit {
pub _args: MarketGroupInitArgs,
}Expand description
Instruction.
Fields
_args: MarketGroupInitArgsTrait Implementations
Sourceimpl BorshDeserialize for MarketGroupInitwhere
MarketGroupInitArgs: BorshDeserialize,
impl BorshDeserialize for MarketGroupInitwhere
MarketGroupInitArgs: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for MarketGroupInitwhere
MarketGroupInitArgs: BorshSerialize,
impl BorshSerialize for MarketGroupInitwhere
MarketGroupInitArgs: BorshSerialize,
Sourceimpl Discriminator for MarketGroupInit
impl Discriminator for MarketGroupInit
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for MarketGroupInit
impl InstructionData for MarketGroupInit