pub struct BuyEvent {
pub trader: Pubkey,
pub token_out: u64,
pub net_cash_in: u64,
pub fee_market_group: u64,
pub fee_tenant: u64,
pub market_state_snapshot: MarketStateSnapshot,
}Fields
trader: Pubkeytoken_out: u64net_cash_in: u64fee_market_group: u64fee_tenant: u64market_state_snapshot: MarketStateSnapshotTrait Implementations
Sourceimpl BorshDeserialize for BuyEvent
impl BorshDeserialize for BuyEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for BuyEvent
impl BorshSerialize for BuyEvent
Sourceimpl Discriminator for BuyEvent
impl Discriminator for BuyEvent
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]