pub struct TenantInitWithAdminAccounts<'info> {
pub payer: AccountInfo<'info>,
pub root: AccountInfo<'info>,
pub tenant_seed: AccountInfo<'info>,
pub tenant: AccountInfo<'info>,
pub system_program: AccountInfo<'info>,
pub log_account: AccountInfo<'info>,
pub mayflower_program: AccountInfo<'info>,
}Expand description
Initialize a platform tenant with an admin.
This instruction is similar to tenant_init but allows specifying an admin
account that will have full control over the tenant.
Arguments
fee_micro_bps- Platform fee rate in micro basis points (1 micro bp = 0.0001%). This fee is taken from all market operations and distributed to the tenant.permissionless_group_creation- If true, anyone can create market groups under this tenant. If false, only the tenant admin can create new groups.admin- Public key of the admin account that will have full control over the tenant.
Fields
payer: AccountInfo<'info>Account paying for the tenant account creation.
root: AccountInfo<'info>Root authority (the program itself) authorizing tenant creation.
tenant_seed: AccountInfo<'info>Seed signer used to derive the tenant’s PDA address.
tenant: AccountInfo<'info>The new tenant account being initialized.
system_program: AccountInfo<'info>System program for creating the tenant account.
log_account: AccountInfo<'info>mayflower_program: AccountInfo<'info>Trait Implementations
Sourceimpl<'info> Accounts<'info, TenantInitWithAdminAccountsBumps> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
impl<'info> Accounts<'info, TenantInitWithAdminAccountsBumps> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
Sourcefn try_accounts(
__program_id: &Pubkey,
__accounts: &mut &'info [AccountInfo<'info>],
__ix_data: &[u8],
__bumps: &mut TenantInitWithAdminAccountsBumps,
__reallocs: &mut BTreeSet<Pubkey>,
) -> Result<Self>
fn try_accounts( __program_id: &Pubkey, __accounts: &mut &'info [AccountInfo<'info>], __ix_data: &[u8], __bumps: &mut TenantInitWithAdminAccountsBumps, __reallocs: &mut BTreeSet<Pubkey>, ) -> Result<Self>
Returns the validated accounts struct. What constitutes “valid” is
program dependent. However, users of these types should never have to
worry about account substitution attacks. For example, if a program
expects a
Mint account from the SPL token program in a particular
field, then it should be impossible for this method to return Ok if
any other account type is given–from the SPL token program or elsewhere. Read moreSourceimpl<'info> AccountsExit<'info> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
impl<'info> AccountsExit<'info> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
Sourceimpl<'info> Bumps for TenantInitWithAdminAccounts<'info>where
'info: 'info,
impl<'info> Bumps for TenantInitWithAdminAccounts<'info>where
'info: 'info,
Sourcetype Bumps = TenantInitWithAdminAccountsBumps
type Bumps = TenantInitWithAdminAccountsBumps
Struct to hold account bump seeds.
Sourceimpl<'info> ToAccountInfos<'info> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
impl<'info> ToAccountInfos<'info> for TenantInitWithAdminAccounts<'info>where
'info: 'info,
fn to_account_infos(&self) -> Vec<AccountInfo<'info>>
Sourceimpl<'info> ToAccountMetas for TenantInitWithAdminAccounts<'info>
impl<'info> ToAccountMetas for TenantInitWithAdminAccounts<'info>
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl<'info> Freeze for TenantInitWithAdminAccounts<'info>
impl<'info> !RefUnwindSafe for TenantInitWithAdminAccounts<'info>
impl<'info> !Send for TenantInitWithAdminAccounts<'info>
impl<'info> !Sync for TenantInitWithAdminAccounts<'info>
impl<'info> Unpin for TenantInitWithAdminAccounts<'info>
impl<'info> !UnwindSafe for TenantInitWithAdminAccounts<'info>